---
name: Feature Request
about: Suggest an idea for something new to add
labels: "Type: Feature"
---
Include a clear description and an example or even a scholarly source of information about how
the calculation, plot, etc. works
